==> jc-1.4.0.tar.gz: soot/grimp/internal/GInstanceFieldRef.h <==
// public class soot.grimp.internal.GInstanceFieldRef

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class ab8ec73b8644c0c6 soot_grimp_internal_GInstanceFieldRef
// @dep_class 2166ff1c3b2462a3 soot_jimple_internal_AbstractInstanceFieldRef

// header file dependencies
// @dep_header soot_jimple_internal_AbstractInstanceFieldRef

#include "soot/jimple/internal/AbstractInstanceFieldRef.h"

#ifndef _JC_soot_grimp_internal_GInstanceFieldRef_H_
#define _JC_soot_grimp_internal_GInstanceFieldRef_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_SootField$object;
struct _jc_soot_Value$object;

// Typedefs
typedef struct _jc_soot_grimp_internal_GInstanceFieldRef$sub_refs	_jc_soot_grimp_internal_GInstanceFieldRef$sub_refs;
typedef struct _jc_soot_grimp_internal_GInstanceFieldRef$sub_nonrefs	_jc_soot_grimp_internal_GInstanceFieldRef$sub_nonrefs;
typedef struct _jc_soot_grimp_internal_GInstanceFieldRef$refs	_jc_soot_grimp_internal_GInstanceFieldRef$refs;
typedef struct _jc_soot_grimp_internal_GInstanceFieldRef$nonrefs	_jc_soot_grimp_internal_GInstanceFieldRef$nonrefs;
typedef struct _jc_soot_grimp_internal_GInstanceFieldRef$object	_jc_soot_grimp_internal_GInstanceFieldRef$object;

typedef const struct _jc_soot_grimp_internal_GInstanceFieldRef$vmethods	_jc_soot_grimp_internal_GInstanceFieldRef$vmethods;
typedef const struct _jc_soot_grimp_internal_GInstanceFieldRef$vtable	_jc_soot_grimp_internal_GInstanceFieldRef$vtable;
typedef const struct _jc_soot_grimp_internal_GInstanceFieldRef$vtype	_jc_soot_grimp_internal_GInstanceFieldRef$vtype;

// Constructors
extern void _jc_soot_grimp_internal_GInstanceFieldRef$method$_init$89791f28adbff691(_jc_env *, struct _jc_soot_grimp_internal_GInstanceFieldRef$object *, struct _jc_object *, struct _jc_soot_SootField$object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_grimp_internal_GInstanceFieldRef$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_grimp_internal_GInstanceFieldRef$object *);
extern jint _jc_soot_grimp_internal_GInstanceFieldRef$method$getPrecedence$9873747576c8b2e5(_jc_env *, struct _jc_soot_grimp_internal_GInstanceFieldRef$object *);
extern struct _jc_java_lang_String$object *_jc_soot_grimp_internal_GInstanceFieldRef$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_grimp_internal_GInstanceFieldRef$object *);
extern struct _jc_java_lang_String$object *_jc_soot_grimp_internal_GInstanceFieldRef$method$toString$dff3eb3766ed852d(_jc_env *, struct _jc_soot_grimp_internal_GInstanceFieldRef$object *, struct _jc_object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_grimp_internal_GInstanceFieldRef$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_grimp_internal_GInstanceFieldRef$method_info$getPrecedence$9873747576c8b2e5;
extern _jc_method _jc_soot_grimp_internal_GInstanceFieldRef$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_soot_grimp_internal_GInstanceFieldRef$method_info$toString$dff3eb3766ed852d;

// Virtual methods structure
struct _jc_soot_grimp_internal_GInstanceFieldRef$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_grimp_internal_GInstanceFieldRef$object *);
	jint	(*getPrecedence$9873747576c8b2e5)(_jc_env *, struct _jc_soot_grimp_internal_GInstanceFieldRef$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_grimp_internal_GInstanceFieldRef$object *);
	struct _jc_java_lang_String$object	*(*toString$dff3eb3766ed852d)(_jc_env *, struct _jc_soot_grimp_internal_GInstanceFieldRef$object *, struct _jc_object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *);
};

// Vtable
struct _jc_soot_grimp_internal_GInstanceFieldRef$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractInstanceFieldRef$vmethods	soot_jimple_internal_AbstractInstanceFieldRef;
	_jc_soot_grimp_internal_GInstanceFieldRef$vmethods	soot_grimp_internal_GInstanceFieldRef;
};

// Vtype
struct _jc_soot_grimp_internal_GInstanceFieldRef$vtype {
	_jc_type			type;
	_jc_soot_grimp_internal_GInstanceFieldRef$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_grimp_internal_GInstanceFieldRef$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_grimp_internal_GInstanceFieldRef$refs {
    _jc_soot_grimp_internal_GInstanceFieldRef$sub_refs	soot_grimp_internal_GInstanceFieldRef;
    _jc_soot_jimple_internal_AbstractInstanceFieldRef$sub_refs	soot_jimple_internal_AbstractInstanceFieldRef;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_grimp_internal_GInstanceFieldRef$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_grimp_internal_GInstanceFieldRef$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractInstanceFieldRef$sub_nonrefs	soot_jimple_internal_AbstractInstanceFieldRef;
    _jc_soot_grimp_internal_GInstanceFieldRef$sub_nonrefs	soot_grimp_internal_GInstanceFieldRef;
};

// Object instance structure
struct _jc_soot_grimp_internal_GInstanceFieldRef$object {
	_jc_soot_grimp_internal_GInstanceFieldRef$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_grimp_internal_GInstanceFieldRef$vtype	*vtype;
	_jc_soot_grimp_internal_GInstanceFieldRef$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_grimp_internal_GInstanceFieldRef$vtype _jc_soot_grimp_internal_GInstanceFieldRef$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_grimp_internal_GInstanceFieldRef, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_grimp_internal_GInstanceFieldRef$class_object;

#endif	/* _JC_soot_grimp_internal_GInstanceFieldRef_H_ */

==> jc-1.4.6.tar.gz: soot/grimp/internal/GInstanceFieldRef.h <==
// public class soot.grimp.internal.GInstanceFieldRef

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class ab8ec73b8644c0c6 soot_grimp_internal_GInstanceFieldRef
// @dep_class 2166ff1c3b2462a3 soot_jimple_internal_AbstractInstanceFieldRef

// header file dependencies
// @dep_header soot_jimple_internal_AbstractInstanceFieldRef

#include "soot/jimple/internal/AbstractInstanceFieldRef.h"

#ifndef _JC_soot_grimp_internal_GInstanceFieldRef_H_
#define _JC_soot_grimp_internal_GInstanceFieldRef_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_SootField$object;
struct _jc_soot_Value$object;

// Typedefs
typedef struct _jc_soot_grimp_internal_GInstanceFieldRef$sub_refs	_jc_soot_grimp_internal_GInstanceFieldRef$sub_refs;
typedef struct _jc_soot_grimp_internal_GInstanceFieldRef$sub_nonrefs	_jc_soot_grimp_internal_GInstanceFieldRef$sub_nonrefs;
typedef struct _jc_soot_grimp_internal_GInstanceFieldRef$refs	_jc_soot_grimp_internal_GInstanceFieldRef$refs;
typedef struct _jc_soot_grimp_internal_GInstanceFieldRef$nonrefs	_jc_soot_grimp_internal_GInstanceFieldRef$nonrefs;
typedef struct _jc_soot_grimp_internal_GInstanceFieldRef$object	_jc_soot_grimp_internal_GInstanceFieldRef$object;

typedef const struct _jc_soot_grimp_internal_GInstanceFieldRef$vmethods	_jc_soot_grimp_internal_GInstanceFieldRef$vmethods;
typedef const struct _jc_soot_grimp_internal_GInstanceFieldRef$vtable	_jc_soot_grimp_internal_GInstanceFieldRef$vtable;
typedef const struct _jc_soot_grimp_internal_GInstanceFieldRef$vtype	_jc_soot_grimp_internal_GInstanceFieldRef$vtype;

// Constructors
extern void _jc_soot_grimp_internal_GInstanceFieldRef$method$_init$89791f28adbff691(_jc_env *, struct _jc_soot_grimp_internal_GInstanceFieldRef$object *, struct _jc_object *, struct _jc_soot_SootField$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_grimp_internal_GInstanceFieldRef$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_grimp_internal_GInstanceFieldRef$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_grimp_internal_GInstanceFieldRef$method$getPrecedence$9873747576c8b2e5(_jc_env *, struct _jc_soot_grimp_internal_GInstanceFieldRef$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_grimp_internal_GInstanceFieldRef$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_grimp_internal_GInstanceFieldRef$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_grimp_internal_GInstanceFieldRef$method$toString$dff3eb3766ed852d(_jc_env *, struct _jc_soot_grimp_internal_GInstanceFieldRef$object *, struct _jc_object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_grimp_internal_GInstanceFieldRef$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_grimp_internal_GInstanceFieldRef$method_info$getPrecedence$9873747576c8b2e5;
extern _jc_method _jc_soot_grimp_internal_GInstanceFieldRef$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_soot_grimp_internal_GInstanceFieldRef$method_info$toString$dff3eb3766ed852d;

// Virtual methods structure
struct _jc_soot_grimp_internal_GInstanceFieldRef$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_grimp_internal_GInstanceFieldRef$object *) _JC_JCNI_ATTR;
	jint	(*getPrecedence$9873747576c8b2e5)(_jc_env *, struct _jc_soot_grimp_internal_GInstanceFieldRef$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_grimp_internal_GInstanceFieldRef$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$dff3eb3766ed852d)(_jc_env *, struct _jc_soot_grimp_internal_GInstanceFieldRef$object *, struct _jc_object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_grimp_internal_GInstanceFieldRef$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractInstanceFieldRef$vmethods	soot_jimple_internal_AbstractInstanceFieldRef;
	_jc_soot_grimp_internal_GInstanceFieldRef$vmethods	soot_grimp_internal_GInstanceFieldRef;
};

// Vtype
struct _jc_soot_grimp_internal_GInstanceFieldRef$vtype {
	_jc_type			type;
	_jc_soot_grimp_internal_GInstanceFieldRef$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_grimp_internal_GInstanceFieldRef$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_grimp_internal_GInstanceFieldRef$refs {
    _jc_soot_grimp_internal_GInstanceFieldRef$sub_refs	soot_grimp_internal_GInstanceFieldRef;
    _jc_soot_jimple_internal_AbstractInstanceFieldRef$sub_refs	soot_jimple_internal_AbstractInstanceFieldRef;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_grimp_internal_GInstanceFieldRef$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_grimp_internal_GInstanceFieldRef$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractInstanceFieldRef$sub_nonrefs	soot_jimple_internal_AbstractInstanceFieldRef;
    _jc_soot_grimp_internal_GInstanceFieldRef$sub_nonrefs	soot_grimp_internal_GInstanceFieldRef;
};

// Object instance structure
struct _jc_soot_grimp_internal_GInstanceFieldRef$object {
	_jc_soot_grimp_internal_GInstanceFieldRef$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_grimp_internal_GInstanceFieldRef$vtype	*vtype;
	_jc_soot_grimp_internal_GInstanceFieldRef$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_grimp_internal_GInstanceFieldRef$vtype _jc_soot_grimp_internal_GInstanceFieldRef$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_grimp_internal_GInstanceFieldRef, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_grimp_internal_GInstanceFieldRef$class_object;

#endif	/* _JC_soot_grimp_internal_GInstanceFieldRef_H_ */
